#!/bin/bash
# -*- coding: utf-8 -*-
#
# «casper-new-uuid» - Creates and injects new UUIDs for casper disks
#
# Create new UUIDs for disks to prevent conflicts and booting the wrong casper
# directory.  Particularly useful in creating recovery disks that need to be
# able to also work with recovery partitioning schemes.
#
# Copyright (C) 2008, Dell Inc.
#
# Author:
#  - Mario Limonciello <Mario_Limonciello@Dell.com>
#
# This script is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this application; if not, write to the Free Software Foundation, Inc., 51
# Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
##################################################################################

INITRD="$1"
OUTPUT="$2"
CASPER_UUID="$3"
COMPRESSOR="$4"

die() {
    echo $* >&2
    exit 1
}

usage() {
    exec >&2
    echo "Usage: $0 <source-initrd> <destination-initrd> <casper-uuid> [compressor]"
    echo "All the pathes should be absolute"
    echo "Optional third parameter could be gzip or lzma, gzip is default"
    exit 1
}

[ "$INITRD" == "" ] && usage
[ "$OUTPUT" == "" ] && usage
[ "$CASPER_UUID" == "" ] && usage
[ "$COMPRESSOR" == "" ] && COMPRESSOR="gzip"

CWD=`pwd`
TEMPDIR=`mktemp -d /tmp/uuid-XXXXXX`

cd $TEMPDIR
echo $TEMPDIR

echo "STARTING"

for compressor in gzip lzma failed; do
    [ "$compressor" == "failed" ] && die "Can not detect initrd image format"
    $compressor -cd < "$INITRD" | cpio -id
    if [ "$?" == '0' ]; then
        echo "Input initrd image seems to be compressed with $compressor"
        break
    fi
done

set -e

uuidgen -r > conf/uuid.conf
find . | cpio --quiet --dereference -o -H newc | $COMPRESSOR -9c > "$OUTPUT" || (rm -f "$OUTPUT"; false)
cp conf/uuid.conf "$CASPER_UUID"
rm -Rf $TEMPDIR
cd $CWD
