#!/bin/bash
set -e

usage() {
    echo "Usage: $0 <isofile> <destdir> [owner]" > /dev/stderr
    exit 1
}

cleanup() {
    if [ -d "$MOUNTDIR" ]; then
        umount -l "$MOUNTDIR" 2>/dev/null || true
        rmdir "$MOUNTDIR"
    fi

    if [ "x$OWNER" != "x" ]; then
        chown -R "$OWNER" "$DESTDIR"
    fi
    chmod -R +rw "$DESTDIR"
}

die() {
    cleanup
    echo ERROR: $* > /dev/stderr
    exit 1
}

ISO="$1"
DESTDIR="$2"
OWNER="$3"

[ "x$ISO" = "x" ] && usage
[ "x$DESTDIR" = "x" ] && usage

MOUNTDIR=`mktemp -d`

trap "die interrupted" INT QUIT
trap "cleanup" EXIT

echo "STARTING"

mkdir -p "$DESTDIR" || die "mkdir failed"
mount -o loop "$ISO" "$MOUNTDIR" || die "Mount failed"
echo "DEBUG: Mounted ISO image $ISO on $MOUNTDIR"

rsync -av "$MOUNTDIR/" "$DESTDIR/"
cleanup
echo
echo "INFO: Done"
