#  Copyright (c) 2010 Vitja Makarov
#
#  Author: Vitja Makarov <vitja.makarov@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from uirk.utils import which, SCRIPTS_DIR, InstallationError, OperationError
from uirk.progress.text import TextSquashfsProgress
import getpass
import os.path

class Unsquashfs(object):
    """Class for extracting files from squashfs images.

        It uses unsquashfs tool, so it should be installed.

        arguments:

        source -- source squashfs file path
        destination -- destination directory
    """

    def __init__(self, source, destination, verbose=False):
        self.source = source
        self.destination = destination
        self.verbose = verbose

    def run(self, progress=None):
        prog = which('unsquashfs')
        if prog is None:
            raise InstallationError, "`unsquashfs' tool not found please install `squashfs-tools' package"

        args = ['unsquashfs', '-f', '-dest', self.destination, self.source]

        if progress is None:
            progress = TextSquashfsProgress
        progress = progress(unsquashfs=True, verbose=self.verbose, obj=self)
        progress.run(self, prog, args)


class Squashfs(object):
    """Class for creating squashfs images"""
    def __init__(self, source, destination, size_fname,
                    exclude=None, exclude_file=None, wildcards=False, regex=False,
                    verbose=False):
        self.source = source
        self.destination = destination
        self.size_fname = size_fname
        self.exclude_file = exclude_file
        self.exclude = exclude
        self.wildcards = wildcards
        self.regex = regex
        self.verbose = verbose

    def run(self, progress=None):
        prog = which('mksquashfs')
        if prog is None:
            raise InstallationError, "`mksquashfs' tool not found please install `squashfs-tools' package"

        helper = os.path.join(SCRIPTS_DIR, 'mksquashfs.sh')

        args = [helper, '%(u)s:%(u)s' % dict(u=getpass.getuser()),
                                self.source, self.destination, self.size_fname,
                                prog, self.source, self.destination]

        if self.wildcards:
            args.append('-wildcards')
        elif self.regex:
            args.append('-regex')
        if self.exclude_file:
            args += ['-ef', self.exclude_file]
        if self.exclude:
            for i in self.exclude:
                args += ['-e', i]

        if progress is None:
            progress = TextSquashfsProgress
        progress = progress(verbose=self.verbose, obj=self)
        ret = progress.run(self, helper, args)
        if ret != 0:
            raise OperationError, "mkisofs exited with code %d" % ret

if __name__ == "__main__":
    import progress.text
    obj = Unsquashfs('../disk/casper/filesystem.squashfs', 'xxx')
    obj.run(progress.text.TextSquashfsProgress(unsquashfs=True))
